Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2105)

Unified Diff: webkit/renderer/media/crypto/proxy_decryptor.h

Issue 17381007: EME: ProxyDecryptor creates MediaKeys instead of Decryptor. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: rebase again Created 7 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « webkit/renderer/media/crypto/ppapi_decryptor.cc ('k') | webkit/renderer/media/crypto/proxy_decryptor.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webkit/renderer/media/crypto/proxy_decryptor.h
diff --git a/webkit/renderer/media/crypto/proxy_decryptor.h b/webkit/renderer/media/crypto/proxy_decryptor.h
index 54efc8a37e690bfb167f7ad77db11a305dd17dec..0bffe56d942725c2df4a6cf64427d28b993f2b5a 100644
--- a/webkit/renderer/media/crypto/proxy_decryptor.h
+++ b/webkit/renderer/media/crypto/proxy_decryptor.h
@@ -55,10 +55,11 @@ class ProxyDecryptor : public media::MediaKeys {
virtual void CancelKeyRequest(const std::string& session_id) OVERRIDE;
private:
- // Helper functions to create decryptors to handle the given |key_system|.
- scoped_ptr<media::Decryptor> CreateDecryptor(const std::string& key_system);
+ // Helper functions to create MediaKeys to handle the given |key_system|.
+ scoped_ptr<media::MediaKeys> CreateMediaKeys(const std::string& key_system);
+
#if defined(ENABLE_PEPPER_CDMS)
- scoped_ptr<media::Decryptor> CreatePpapiDecryptor(
+ scoped_ptr<media::MediaKeys> CreatePpapiDecryptor(
const std::string& key_system);
// Callback for cleaning up a Pepper CDM.
void DestroyHelperPlugin();
@@ -92,9 +93,9 @@ class ProxyDecryptor : public media::MediaKeys {
media::DecryptorReadyCB decryptor_ready_cb_;
- // The real decryptor that does decryption for the ProxyDecryptor.
+ // The real MediaKeys that manages key operations for the ProxyDecryptor.
// This pointer is protected by the |lock_|.
- scoped_ptr<media::Decryptor> decryptor_;
+ scoped_ptr<media::MediaKeys> media_keys_;
base::WeakPtrFactory<ProxyDecryptor> weak_ptr_factory_;
« no previous file with comments | « webkit/renderer/media/crypto/ppapi_decryptor.cc ('k') | webkit/renderer/media/crypto/proxy_decryptor.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698